==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>De controle is bijna voltooid - bedankt voor je geduld.</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Bezig met voorbereiden…</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>De foutencontrole is voltooid</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Ga naar bureaublad</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Welkom! Het systeem is bijgewerkt.</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Huidige editie:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Logboeken bekijken</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Je systeem is bijgewerkt</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Je computer wordt over %1 herstart</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Je computer wordt over %1 afgesloten</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Het automatisch opnieuw opstarten is mislukt - herstart zelf je apparaat.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Het automatisch afsluiten is mislukt - sluit zelf je apparaat af.</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Logboeken verbergen</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Update mislukt</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Reservekopie mislukt</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Er kan geen reservekopie worden gemaakt. Als je doorgaat met de installatie, dan kun je je systeem niet meer herstellen naar een oudere versie.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Onvoldoende schijfruimte. Maak ruimte vrij en probeer het opnieuw.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Er kan geen verbinding met de reservekopiediensten worden gemaakt.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Er kan geen verbinding met de updatediensten worden gemaakt.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Afhankelijkheidsfout</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG-fout</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Reservekopie opnieuw maken</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Afbreken</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Doorgaan met bijwerken</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Ga naar bureaublad</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Bezig met voorbereiden…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Let op: schakel de computer niet uit tijdens het installeren van de updates, anders kan het systeem beschadigd raken!</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.31.tar.xz: BUILD/src/dde-update/translations/dde-update_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>De controle is bijna voltooid - bedankt voor je geduld.</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Bezig met voorbereiden…</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>De foutencontrole is voltooid</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Ga naar bureaublad</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Welkom! Het systeem is bijgewerkt.</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Huidige editie:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Je systeem is bijgewerkt</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Je computer wordt over %1 herstart</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Je computer wordt over %1 afgesloten</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Het automatisch opnieuw opstarten is mislukt - herstart zelf je apparaat.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Het automatisch afsluiten is mislukt - sluit zelf je apparaat af.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Updatelogboek bekijken</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Updatelogboek sluiten</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Het logboek is opgeslagen op het bureaublad</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Exporteren mislukt - probeer het opnieuw</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Update mislukt</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Reservekopie mislukt</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Er kan geen reservekopie worden gemaakt. Als je doorgaat met de installatie, dan kun je je systeem niet meer herstellen naar een oudere versie.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Onvoldoende schijfruimte. Maak ruimte vrij en probeer het opnieuw.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Er kan geen verbinding met de reservekopiediensten worden gemaakt.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Er kan geen verbinding met de updatediensten worden gemaakt.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Afhankelijkheidsfout</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG-fout</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Reservekopie opnieuw maken</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Afbreken</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Doorgaan met bijwerken</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Ga naar bureaublad</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Bezig met voorbereiden…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Let op: schakel de computer niet uit tijdens het installeren van de updates, anders kan het systeem beschadigd raken!</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Updatelogboek bekijken</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Updatelogboek sluiten</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>updatelog</translation>
    </message>
</context>
</TS>
